<?php
/**
 * Storefront Class
 *
 * @since    1.0.0
 * @package  Sarmaya
 */

if (!defined('ABSPATH')) {
    exit;
}

if (!class_exists('Sarmaya_Theme_Init')):

    /**
     * The main Sarmaya_Theme_Init class
     */
    class Sarmaya_Theme_Init {

        /**
         * Setup class.
         *
         * @since 1.0
         */
        public function __construct() {
            add_action('after_setup_theme', array($this, 'setup'));
            add_action('widgets_init', array($this, 'widgets_init'));
            add_action('wp_enqueue_scripts', array($this, 'scripts'), 11);
            add_action('wp_enqueue_scripts', array($this, 'child_scripts'), 30); // After WooCommerce.
            add_filter('body_class', array($this, 'body_classes'));
            add_action('enqueue_embed_scripts', array($this, 'print_embed_styles'));
        }

        /**
         * Sets up theme defaults and registers support for various WordPress features.
         *
         * Note that this function is hooked into the after_setup_theme hook, which
         * runs before the init hook. The init hook is too late for some features, such
         * as indicating support for post thumbnails.
         */
        public function setup() {

            /*
             * Make theme available for translation.
             * Translations can be filed in the /languages/ directory.
             * If you're building a theme based on Sarmaya, use a find and replace
             * to change 'sarmaya' to the name of your theme in all the template files
             */
            load_theme_textdomain('sarmaya', get_parent_theme_file_path('/languages'));

            /**
             * Add default posts and comments RSS feed links to head.
             */
            add_theme_support('automatic-feed-links');

            /*
             * Let WordPress manage the document title.
             * By adding theme support, we declare that this theme does not use a
             * hard-coded <title> tag in the document head, and expect WordPress to
             * provide it for us.
             */
            add_theme_support('title-tag');

            /**
             * Filter Sarmaya's custom-background support argument.
             *
             * @param array $args {
             *     An array of custom-background support arguments.
             * }
             */
            $args = array(
                'default-color' => 'ffffff',
            );
            add_theme_support('custom-background', $args);

            /*
             * Enable support for Post Thumbnails on posts and pages.
             *
             * @link https://developer.wordpress.org/reference/functions/add_theme_support/#Post_Thumbnails
             */
            add_theme_support('post-thumbnails');
            add_image_size('sarmaya-featured-image', 1736, 9999, false);

            // Set the content width in pixels, based on the theme's design and stylesheet.
            $GLOBALS['content_width'] = apply_filters('sarmaya_content_width', 700);

            /*
             * This theme uses wp_nav_menu() in the following locations.
             */
            register_nav_menus(
                array(
                    'primary' => esc_html__('Primary Menu', 'sarmaya'),
                    'footer'  => esc_html__('Footer Menu', 'sarmaya'),
                    'social'  => esc_html__('Social Menu', 'sarmaya'),
                )

            );

            /*
             * Enable support for the WordPress default Theme Logo
             * See: https://codex.wordpress.org/Theme_Logo
             */
            add_theme_support(
                'custom-logo', array(
                    'flex-width' => true,
                )
            );

            /*
             * Enable support for Customizer Selective Refresh.
             * See: https://make.wordpress.org/core/2016/02/16/selective-refresh-in-the-customizer/
             */
            add_theme_support('customize-selective-refresh-widgets');

            /*
             * Switch default core markup for search form, comment form, comments, galleries, captions and widgets
             * to output valid HTML5.
             */
            add_theme_support(
                'html5', apply_filters(
                    'sarmaya_html5_args', array(
                        'search-form',
                        'comment-form',
                        'comment-list',
                        'gallery',
                        'caption',
                        'widgets',
                    )
                )
            );

            /**
             * Custom colors for use in the editor.
             *
             * @link https://wordpress.org/gutenberg/handbook/reference/theme-support/
             */
            add_theme_support(
                'editor-color-palette', array(
                    array(
                        'name'  => esc_html__('Dark', 'sarmaya'),
                        'slug'  => 'dark',
                        'color' => '#111111',
                    ),
                    array(
                        'name'  => esc_html__('Light dark', 'sarmaya'),
                        'slug'  => 'light-dark',
                        'color' => '#242424',
                    ),
                    array(
                        'name'  => esc_html__('Gray', 'sarmaya'),
                        'slug'  => 'gray',
                        'color' => '#999999',
                    ),
                    array(
                        'name'  => esc_html__('Light Gray', 'sarmaya'),
                        'slug'  => 'light-gray',
                        'color' => '#b5c4c7',
                    ),
                    array(
                        'name'  => esc_html__('White', 'sarmaya'),
                        'slug'  => 'white',
                        'color' => '#ffffff',
                    ),
                    array(
                        'name'  => esc_html__('Dark blue', 'sarmaya'),
                        'slug'  => 'dark-blue',
                        'color' => '#232368',
                    ),
                    array(
                        'name'  => esc_html__('Blue', 'sarmaya'),
                        'slug'  => 'blue',
                        'color' => '#341fff',
                    ),
                    array(
                        'name'  => esc_html__('Cream', 'sarmaya'),
                        'slug'  => 'cream',
                        'color' => '#fff0e0',
                    )

                )
            );

            /**
             * Custom font sizes for use in the editor.
             *
             * @link https://wordpress.org/gutenberg/handbook/extensibility/theme-support/#block-font-sizes
             */
            add_theme_support(
                'editor-font-sizes', array(
                    array(
                        'name'      => esc_html__('Small', 'sarmaya'),
                        'shortName' => esc_html__('S', 'sarmaya'),
                        'size'      => 16,
                        'slug'      => 'small',
                    ),
                    array(
                        'name'      => esc_html__('Regular', 'sarmaya'),
                        'shortName' => esc_html__('M', 'sarmaya'),
                        'size'      => 19,
                        'slug'      => 'regular',
                    ),
                    array(
                        'name'      => esc_html__('Large', 'sarmaya'),
                        'shortName' => esc_html__('L', 'sarmaya'),
                        'size'      => 24,
                        'slug'      => 'large',
                    ),
                    array(
                        'name'      => esc_html__('Huge', 'sarmaya'),
                        'shortName' => esc_html__('XL', 'sarmaya'),
                        'size'      => 32,
                        'slug'      => 'huge',
                    ),
                )
            );

            // Add support for default block styles.
            add_theme_support('wp-block-styles');

            // Enable support for responsive embedded content
            add_theme_support('responsive-embeds');

            // Add support for full and wide align images.
            add_theme_support('align-wide');

            // Add support for editor styles.
            add_theme_support('editor-styles');

            // Enqueue editor styles.
            add_editor_style('assets/css/style-editor.css');

            // Enqueue fonts in the editor.
            add_editor_style($this->googleFonts());

            /*
             * Define starter content for the theme.
             * See: https://make.wordpress.org/core/2016/11/30/starter-content-for-themes-in-4-7/
             */
            $starter_content = array(
                'options'     => array(
                    'show_on_front' => 'page',
                    'page_on_front' => '{{home}}',
                ),

                'attachments' => array(
                    'image-logo' => array(
                        'post_title' => _x('Logo', 'Theme starter content', 'sarmaya'),
                        'file'       => 'assets/images/logo.png',
                    ),
                ),

                'theme_mods'  => array(
                    'show_on_front'         => 'page',
                    'page_for_posts'        => '{{blog}}',
                    'blogdescription'       => _x('Sarmaya, A beautiful Gutenberg WordPress theme', 'Theme starter content', 'sarmaya'),
                    'custom_logo'           => '{{image-logo}}',
                    'custom_logo_max_width' => sarmaya_defaults('logo_max_width'),
                ),

                'widgets'     => array(
                    'sidebar-1' => array(
                        'text_about',
                    ),
                ),

                'nav_menus'   => array(
                    'primary' => array(
                        'name'  => esc_html__('Primary Menu', 'sarmaya'),
                        'items' => array(
                            'page_blog'    => array(
                                'title' => _x('Articles', 'Theme starter content', 'sarmaya'),
                            ),
                            'page_about'   => array(
                                'title' => _x('About', 'Theme starter content', 'sarmaya'),
                            ),
                            'page_contact' => array(
                                'title' => _x('Contact', 'Theme starter content', 'sarmaya'),
                            ),
                        ),
                    ),
                    'social'  => array(
                        'name'  => esc_html__('Social Menu', 'sarmaya'),
                        'items' => array(
                            'link_twitter',
                            'link_instagram',
                        ),
                    ),
                ),
            );

            /**
             * Filters Sarmaya array of starter content.
             *
             * @since Sarmaya 1.0
             *
             * @param array $starter_content Array of starter content.
             */
            $starter_content = apply_filters('sarmaya_starter_content', $starter_content);

            add_theme_support('starter-content', $starter_content);

            /**
             *  Add support for the Site Logo plugin and the site logo functionality in JetPack
             *  https://github.com/automattic/site-logo
             *  http://jetpack.me/
             */
            add_theme_support(
                'site-logo', apply_filters(
                    'sarmaya_site_logo_args', array(
                        'size' => 'full',
                    )
                )
            );

        }

        /**
         * Register widget area.
         *
         * @link https://codex.wordpress.org/Function_Reference/register_sidebar
         */
        public function widgets_init() {
            $sidebar_args['sidebar'] = array(
                'name'        => __('Sidebar', 'sarmaya'),
                'id'          => 'sidebar-1',
                'description' => '',
            );
            
            $sidebar_args['pagesidebar'] = array(
                'name'        => __('Page Sidebar', 'sarmaya'),
                'id'          => 'page-sidebar',
                'description' => '',
            );

            $sidebar_args['shop'] = array(
                'name'        => __('Shop', 'sarmaya'),
                'id'          => 'shop-1',
                'description' => '',
            );

            $rows    = intval(apply_filters('sarmaya_footer_widget_rows', 1));
            $regions = intval(apply_filters('sarmaya_footer_widget_columns', 5));

            for ($row = 1; $row <= $rows; $row++) {
                for ($region = 1; $region <= $regions; $region++) {
                    $footer_n = $region + $regions * ($row - 1); // Defines footer sidebar ID.
                    $footer   = sprintf('footer_%d', $footer_n);

                    if (1 === $rows) {
                        /* translators: 1: column number */
                        $footer_region_name = sprintf(__('Footer Column %1$d', 'sarmaya'), $region);

                        /* translators: 1: column number */
                        $footer_region_description = sprintf(__('Widgets added here will appear in column %1$d of the footer.', 'sarmaya'), $region);
                    } else {
                        /* translators: 1: row number, 2: column number */
                        $footer_region_name = sprintf(__('Footer Row %1$d - Column %2$d', 'sarmaya'), $row, $region);

                        /* translators: 1: column number, 2: row number */
                        $footer_region_description = sprintf(__('Widgets added here will appear in column %1$d of footer row %2$d.', 'sarmaya'), $region, $row);
                    }

                    $sidebar_args[$footer] = array(
                        'name'        => $footer_region_name,
                        'id'          => sprintf('footer-%d', $footer_n),
                        'description' => $footer_region_description,
                    );
                }
            }

            $sidebar_args = apply_filters('sarmaya_sidebar_args', $sidebar_args);

            foreach ($sidebar_args as $sidebar => $args) {
                $widget_tags = array(
                    'before_widget' => '<div id="%1$s" class="widget %2$s">',
                    'after_widget'  => '</div>',
                    'before_title'  => '<span class="gamma widget-title">',
                    'after_title'   => '</span>',
                );

                /**
                 * Dynamically generated filter hooks. Allow changing widget wrapper and title tags. See the list below.
                 *
                 * 'sarmaya_header_widget_tags'
                 * 'sarmaya_sidebar_widget_tags'
                 *
                 * 'sarmaya_footer_1_widget_tags'
                 * 'sarmaya_footer_2_widget_tags'
                 * 'sarmaya_footer_3_widget_tags'
                 * 'sarmaya_footer_4_widget_tags'
                 */
                $filter_hook = sprintf('sarmaya_%s_widget_tags', $sidebar);
                $widget_tags = apply_filters($filter_hook, $widget_tags);

                if (is_array($widget_tags)) {
                    register_sidebar($args + $widget_tags);
                }
            }
        }

        /**
         * Enqueue scripts and styles.
         *
         * @since  1.0.0
         */
        public function scripts() {
            global $sarmaya_version;

            /**
             * Styles
             */

            // Add bootstrap css
            wp_enqueue_style('bootstrap', get_theme_file_uri('/assets/css/bootstrap.min.css'), false, '1.0.4', 'all');

            // Add fontawesome fonts.
            wp_enqueue_style('fontawesome', get_theme_file_uri('/assets/css/fontawesome-all.min.css'), false, '1.0.4', 'all');

            // Theme stylesheet.
            wp_enqueue_style('sarmaya-style', get_stylesheet_uri(), array(), wp_get_theme()->get('Version'));

            /**
             * Fonts
             */
            wp_enqueue_style('sarmaya-fonts', $this->googleFonts(), array(), null);

            /**
             * Scripts
             */

            // bootstrap js
            wp_enqueue_script('bootstrap', get_theme_file_uri('/assets/js/bootstrap.bundle.min.js'), array('jquery'), '1.0.4', true);

            // global js
            wp_enqueue_script('sarmaya-global', get_theme_file_uri('/assets/js/global.js'), array('jquery'), '1.0.4', true);

            // Load the standard WordPress comments reply javascript.
            if (is_singular('post') && comments_open() && get_option('thread_comments')) {
                wp_enqueue_script('comment-reply');
            }

            if (has_nav_menu('handheld')) {
                $sarmaya_l10n = array(
                    'expand'   => __('Expand child menu', 'sarmaya'),
                    'collapse' => __('Collapse child menu', 'sarmaya'),
                );

                wp_localize_script('sarmaya-navigation', 'sarmayaScreenReaderText', $sarmaya_l10n);
            }

            if (is_singular() && comments_open() && get_option('thread_comments')) {
                wp_enqueue_script('comment-reply');
            }

        }

        /**
         * Register Google fonts.
         *
         * @since 1.0.0
         * @return string Google fonts URL for the theme.
         */
        public function googleFonts() {

            $google_font_families  = array(
                'Josefinsans' => 'Poppins:400,500,700',
            );

            if (get_theme_mod('sarmaya_headings_font', sarmaya_defaults( 'headings_font' ))) {
                $google_font_families['heading'] = get_theme_mod('sarmaya_headings_font', sarmaya_defaults( 'headings_font' )) . ':' . get_theme_mod('sarmaya_headings_font_weight', sarmaya_defaults( 'headings_font_weight' ));
            }
            if (get_theme_mod('sarmaya_body_font', sarmaya_defaults( 'body_font' ))) {
                $google_font_families['body'] = get_theme_mod('sarmaya_body_font', sarmaya_defaults( 'body_font' )) . ':' . get_theme_mod('sarmaya_body_font_weight', sarmaya_defaults( 'body_font_weight' ));
            }

            $google_fonts = apply_filters( 'sarmaya_google_font_families', $google_font_families );

            $query_args = array(
                'family' => implode('%7C', $google_fonts),
                'subset' => rawurlencode('latin,latin-ext'),
            );

            $fonts_url = add_query_arg($query_args, 'https://fonts.googleapis.com/css');

            return $fonts_url;
        }

        /**
         * Enqueue child theme stylesheet.
         * A separate function is required as the child theme css needs to be enqueued _after_ the parent theme
         * primary css and the separate WooCommerce css.
         *
         * @since  1.0.1
         */
        public function child_scripts() {
            if (is_child_theme()) {
                $child_theme = wp_get_theme(get_stylesheet());
                wp_enqueue_style('sarmaya-child-style', get_stylesheet_uri(), array(), $child_theme->get('Version'));
            }
        }

        /**
         * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
         *
         * @param array $args Configuration arguments.
         * @return array
         */
        public function pageMenuArgs($args) {
            $args['show_home'] = true;
            return $args;
        }

        /**
         * Adds custom classes to the array of body classes.
         *
         * @param array $classes Classes for the body element.
         * @return array
         */
        public function body_classes($classes) {

            /**
             * Adds a class when WooCommerce is not active.
             *
             * @todo Refactor child themes to remove dependency on this class.
             */
            $classes[] = 'no-wc-breadcrumb';

            // Add class if align-wide is supported.
            if (current_theme_supports('align-wide')) {
                $classes[] = 'sarmaya-align-wide';
            }

            return $classes;
        }

        
    }

endif;

return new Sarmaya_Theme_Init();
