<?php
/**
 * Sarmaya WooCommerce Class
 *
 * @package  sarmaya
 * @since    2.0.0
 */

if (!defined('ABSPATH')) {
    exit;
}

if (!class_exists('Sarmaya_WooCommerce')):

    /**
     * The Sarmaya WooCommerce Integration class
     */
    class Sarmaya_WooCommerce {

        /**
         * Setup class.
         *
         * @since 1.0
         */
        public function __construct() {
            add_action('after_setup_theme', array($this, 'setup'));
            add_filter('body_class', array($this, 'woocommerce_body_class'));
            add_action('wp_enqueue_scripts', array($this, 'woocommerce_scripts'), 10);
            add_filter('woocommerce_enqueue_styles', array($this, 'dequeue_styles'));
            add_filter('woocommerce_output_related_products_args', array($this, 'related_products_args'));
            add_filter('woocommerce_breadcrumb_defaults', array($this, 'change_breadcrumb_delimiter'));

        }

        /**
         * Sets up theme defaults and registers support for various WooCommerce features.
         *
         * Note that this function is hooked into the after_setup_theme hook, which
         * runs before the init hook. The init hook is too late for some features, such
         * as indicating support for post thumbnails.
         *
         * @since 1.0.0
         * @return void
         */
        public function setup() {
            add_theme_support(
                'woocommerce', apply_filters(
                    'sarmaya_woocommerce_args', array(
                        'thumbnail_image_width' => 400,
                        'single_image_width' => 650,
                        'gallery_thumbnail_image_width' => 150,
                        'product_grid'                  => array(
                            'default_columns' => 3,
                            'default_rows'    => 4,
                            'min_columns'     => 1,
                            'max_columns'     => 6,
                            'min_rows'        => 1,
                        ),
                    )
                )
            );

            add_theme_support('wc-product-gallery-zoom');
            add_theme_support('wc-product-gallery-lightbox');
            add_theme_support('wc-product-gallery-slider');

 

            /**
             * Add 'sarmaya_woocommerce_setup' action.
             *
             * @since  1.0.0
             */
            do_action('sarmaya_woocommerce_setup');
        }

        /**
         * Disable the default stylesheet
         *
         * @since 1.0
         * @return void
         */
        public function dequeue_styles($enqueue_styles) {
            unset($enqueue_styles['woocommerce-general']); // Remove the gloss
            //unset( $enqueue_styles['woocommerce-layout'] );        // Remove the layout
            //unset( $enqueue_styles['woocommerce-smallscreen'] );    // Remove the smallscreen optimisation
            return $enqueue_styles;
        }

        /**
         * Add WooCommerce specific classes to the body tag
         *
         * @param  array $classes css classes applied to the body tag.
         * @return array $classes modified to include 'woocommerce-active' class
         */
        public function woocommerce_body_class($classes) {
            $classes[] = 'woocommerce-active';

            // Remove `no-wc-breadcrumb` body class.
            $key = array_search('no-wc-breadcrumb', $classes, true);

            if (false !== $key) {
                unset($classes[$key]);
            }

            return $classes;
        }

        /**
         * WooCommerce specific scripts & stylesheets
         *
         * @since 1.0.0
         */
        public function woocommerce_scripts() {
            global $sarmaya_version;

            // Add woocommerce css.
            wp_enqueue_style('sarmaya-woocommerce-style', get_theme_file_uri('/assets/css/woocommerce.css'), array(), '1.0.4');

            wp_register_script('sarmaya-header-cart', get_template_directory_uri() . '/assets/js/woocommerce/header-cart.js', array(), $sarmaya_version, true);
            wp_enqueue_script('sarmaya-header-cart');

        }

        /**
         * Related Products Args
         *
         * @param  array $args related products args.
         * @since 1.0.0
         * @return  array $args related products args
         */
        public function related_products_args($args) {

            $page_layout = get_theme_mod('sarmaya_woocommerce_single_product_layout', sarmaya_defaults('woocommerce_single_product_layout'));

            if ($page_layout !== 'full_width') {
                $args = apply_filters(
                    'sarmaya_related_products_args', array(
                        'posts_per_page' => 4,
                        'columns'        => 4,
                    )
                );
            }

            return $args;
        }

        /**
         * Remove the breadcrumb delimiter
         *
         * @param  array $defaults The breadcrumb defaults.
         * @return array           The breadcrumb defaults.
         * @since 1.0.0
         */
        public function change_breadcrumb_delimiter($defaults) {
            $defaults['delimiter']   = '';
            $defaults['wrap_before'] = '<nav aria-label="breadcrumb"> <ol class="breadcrumb">';
            $defaults['wrap_after']  = '</nav></ol>';
            $defaults['before']      = '<li class="breadcrumb-item">';
            $defaults['after']       = '</li>';
            return $defaults;
        }

    }

endif;

return new Sarmaya_WooCommerce();
